@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = "0.001";
+our $VERSION = "0.002";
 $VERSION = eval $VERSION;
 
 our @BACKENDS = (
-    Clone       => "clone",
+    Clone       => [0.10, "clone"],
     Storable    => "dclone",
     "Clone::PP" => "clone",
 );
@@ -19,10 +19,14 @@ BEGIN
 {
     unless ($use_m)
     {
-        eval "use Module::Runtime (); 1;" and $use_m = Module::Runtime->can("use_module");
+        eval "use Module::Runtime (); 1;"
+          and $use_m = Module::Runtime->can("use_module")
+          unless $ENV{CLONE_CHOOSE_NO_MODULE_RUNTIME};
         $use_m ||= sub {
-            my $pkg = shift;
-            eval "use $pkg";
+            my ($pkg, @imports) = @_;
+            my $use_stmt = "use $pkg";
+            @imports and $use_stmt = join(" ", $use_stmt, @imports);
+            eval $use_stmt;
             $@ and die $@;
             1;
         };
@@ -40,9 +44,9 @@ sub can
     my $fn;
     while (my ($pkg, $rout) = splice @backends, 0, 2)
     {
-        eval { $use_m->($pkg); 1; } or next;
+        eval { $use_m->($pkg, ref $rout ? ($rout->[0]) : ()); 1; } or next;
 
-        $fn = $pkg->can($rout);
+        $fn = $pkg->can(ref $rout ? $rout->[1] : $rout);
         $fn or next;
 
         last;
@@ -54,7 +58,7 @@ sub can
 sub import
 {
     my ($me, @params) = @_;
-    my $tgt = caller(1);
+    my $tgt = caller(0);
 
     my @B = @BACKENDS;
     local @BACKENDS = @B;
@@ -63,11 +67,7 @@ sub import
 
     while (my $param = shift @params)
     {
-        if ($param =~ m/^\d/)
-        {
-            Carp::croak "Clone::Choose version $param required. This is only version $VERSION" if $VERSION < $param;
-        }
-        elsif ($param =~ m/^:(.*)$/)
+        if ($param =~ m/^:(.*)$/)
         {
             my $favourite = $1;
             my %b         = @BACKENDS;
@@ -77,12 +77,13 @@ sub import
         elsif ($param eq "clone")
         {
             my $fn = __PACKAGE__->can("clone");
-            $fn or return;
+            $fn or Carp::croak "Cannot find an apropriate clone().";
 
             no strict "refs";
-            *{"$tgt\::clone"} = $fn;
+            *{"${tgt}::clone"} = $fn;
 
-            @params and Carp::croak "Parameters left after clone. Please see description.";
+            @params
+              and Carp::croak "Parameters left after clone. Please see description.";
 
             return;
         }
